
Theo, the order system
======================

First of all, welcome to Theo and/or the Rattail Project in general.

Theo offers various features with an aim to be "the order system" for
an organization (or at least as much of one as is needed).  It is
meant to integrate with the POS system.

The target audience is natural food retailers, but other orgs may
still give it a look.

Primary features include:

* tools to browse and/or manage customer and product data
* tools to create and manage "customer orders" (aka. case orders, special orders)
* tools to assist with "purchasing workflows" (aka. ordering, receiving, credits)
* tools to report on / visualize order data etc.

Please see `https://rattailproject.org/docs/theo/
<https://rattailproject.org/docs/theo/>`_ for the latest version of this
document.

.. toctree::
   :maxdepth: 1

   quickstart
   features
   demo
   install/index
   develop


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
